@@ -31,11 +31,12 @@ test_that("human gene sets overall stats", {
   expect_identical(msigdbr_hs, msigdbr(species = "human"))
   expect_gt(nrow(msigdbr_hs), 4200000)
   expect_identical(colnames(msigdbr_hs)[1:6], c("gs_cat", "gs_subcat", "gs_name", "gene_symbol", "entrez_gene", "ensembl_gene"))
-  expect_gt(n_distinct(msigdbr_hs$gene_symbol), 39000)
-  expect_gt(n_distinct(msigdbr_hs$entrez_gene), 39000)
-  expect_gt(n_distinct(msigdbr_hs$ensembl_gene), 39000)
+  expect_gt(n_distinct(msigdbr_hs$gene_symbol), 40000)
+  expect_gt(n_distinct(msigdbr_hs$entrez_gene), 40000)
+  expect_gt(n_distinct(msigdbr_hs$ensembl_gene), 40000)
   expect_equal(min(rle(msigdbr_hs$gs_id)$lengths), 5)
-  expect_lt(max(rle(msigdbr_hs$gs_id)$lengths), 2500)
+  expect_lt(max(rle(msigdbr_hs$gs_id)$lengths), 2800)
+  expect_lt(quantile(rle(msigdbr_hs$gs_id)$lengths, 0.999), 2000)
   msigdbr_hs_sym <- distinct(msigdbr_hs, gs_id, gene_symbol)
   expect_gt(nrow(msigdbr_hs_sym), 3800000)
   expect_lt(max(rle(msigdbr_hs_sym$gs_id)$lengths), 2005)
@@ -45,12 +46,12 @@ test_that("mouse gene sets overall stats", {
   msigdbr_mm <- msigdbr(species = "Mus musculus")
   expect_s3_class(msigdbr_mm, "tbl_df")
   expect_identical(msigdbr_mm, msigdbr(species = "mouse"))
-  expect_gt(nrow(msigdbr_mm), 3800000)
+  expect_gt(nrow(msigdbr_mm), 3700000)
   expect_identical(colnames(msigdbr_mm)[1:6], c("gs_cat", "gs_subcat", "gs_name", "gene_symbol", "entrez_gene", "ensembl_gene"))
-  expect_gt(n_distinct(msigdbr_mm$human_gene_symbol), 19000)
-  expect_gt(n_distinct(msigdbr_mm$gene_symbol), 18000)
-  expect_gt(n_distinct(msigdbr_mm$entrez_gene), 18000)
-  expect_gt(n_distinct(msigdbr_mm$ensembl_gene), 18000)
+  expect_gt(n_distinct(msigdbr_mm$human_gene_symbol), 18000)
+  expect_gt(n_distinct(msigdbr_mm$gene_symbol), 17000)
+  expect_gt(n_distinct(msigdbr_mm$entrez_gene), 17000)
+  expect_gt(n_distinct(msigdbr_mm$ensembl_gene), 17000)
   expect_equal(max(msigdbr_mm$num_ortholog_sources), 12)
 })
 
@@ -58,7 +59,7 @@ test_that("rat gene sets overall stats", {
   msigdbr_rn <- msigdbr(species = "Rattus norvegicus")
   expect_s3_class(msigdbr_rn, "tbl_df")
   expect_identical(msigdbr_rn, msigdbr(species = "rat"))
-  expect_gt(nrow(msigdbr_rn), 3700000)
+  expect_gt(nrow(msigdbr_rn), 3600000)
   expect_gt(n_distinct(msigdbr_rn$human_gene_symbol), 15000)
   expect_gt(n_distinct(msigdbr_rn$gene_symbol), 15000)
   expect_equal(max(msigdbr_rn$num_ortholog_sources), 10)
@@ -150,10 +151,12 @@ test_that("number of genes in specific gene sets", {
   expect_equal(nrow(filter(msigdbr_mm, gs_id == "M40020")), 12)
   expect_equal(nrow(filter(msigdbr_hs, gs_id == "M490")), 57)
   expect_equal(nrow(filter(msigdbr_hs_sym, gs_id == "M490")), 55)
-  expect_equal(nrow(filter(msigdbr_mm, gs_id == "M490")), 55)
-  expect_equal(nrow(filter(msigdbr_hs, gs_id == "M40180")), 90)
-  expect_equal(nrow(filter(msigdbr_hs_sym, gs_id == "M40180")), 90)
-  expect_equal(nrow(filter(msigdbr_mm, gs_id == "M40180")), 88)
+  expect_gt(nrow(filter(msigdbr_mm, gs_id == "M490")), 50)
+  expect_lt(nrow(filter(msigdbr_mm, gs_id == "M490")), 60)
+  expect_equal(nrow(filter(msigdbr_hs, gs_id == "M40180")), 91)
+  expect_equal(nrow(filter(msigdbr_hs_sym, gs_id == "M40180")), 91)
+  expect_gt(nrow(filter(msigdbr_mm, gs_id == "M40180")), 80)
+  expect_lt(nrow(filter(msigdbr_mm, gs_id == "M40180")), 95)
 })
 
 test_that("wrong msigdbr() parameters", {
